summaryrefslogtreecommitdiffstats
path: root/kaddressbook/kaddressbookview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/kaddressbookview.cpp')
-rw-r--r--kaddressbook/kaddressbookview.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kaddressbook/kaddressbookview.cpp b/kaddressbook/kaddressbookview.cpp
index 00212a5f..43d709d2 100644
--- a/kaddressbook/kaddressbookview.cpp
+++ b/kaddressbook/kaddressbookview.cpp
@@ -21,7 +21,7 @@
without including the source code for TQt in the source distribution.
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpopupmenu.h>
#include <kabc/addressbook.h>
@@ -121,12 +121,12 @@ KABC::Addressee::List KAddressBookView::addressees()
void KAddressBookView::initGUI()
{
- // Create the layout
- TQVBoxLayout *layout = new TQVBoxLayout( this );
+ // Create the tqlayout
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
// Add the view widget
mViewWidget = new TQWidget( this );
- layout->addWidget( mViewWidget );
+ tqlayout->addWidget( mViewWidget );
}
KABC::Field::List KAddressBookView::fields() const